"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_ManagedInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_INSTANCES_DATABASES_FIELD_NUMBER: builtins.int
    @property
    def managed_instances_databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabases]: ...
    def __init__(
        self,
        *,
        managed_instances_databases: collections.abc.Iterable[global___ManagedInstancesDatabases] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_instances_databases", b"managed_instances_databases"]) -> None: ...

global___Microsoft_Sql_ManagedInstances = Microsoft_Sql_ManagedInstances

@typing_extensions.final
class ManagedInstancesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ManagedInstancesVulnerabilityAssessments = ManagedInstancesVulnerabilityAssessments

@typing_extensions.final
class ManagedInstancesSqlAgent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___ManagedInstancesSqlAgent = ManagedInstancesSqlAgent

@typing_extensions.final
class ManagedInstancesServerTrustCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_BLOB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    public_blob: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        public_blob: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "public_blob", b"public_blob", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesServerTrustCertificates = ManagedInstancesServerTrustCertificates

@typing_extensions.final
class ManagedInstancesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ManagedInstancesSecurityAlertPolicies = ManagedInstancesSecurityAlertPolicies

@typing_extensions.final
class ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    retention_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        retention_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies = ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___ManagedInstancePrivateEndpointProperty: ...
    @property
    def private_link_service_connection_state(self) -> global___ManagedInstancePrivateLinkServiceConnectionStateProperty: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___ManagedInstancePrivateEndpointProperty | None = ...,
        private_link_service_connection_state: global___ManagedInstancePrivateLinkServiceConnectionStateProperty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesPrivateEndpointConnections = ManagedInstancesPrivateEndpointConnections

@typing_extensions.final
class ManagedInstancePrivateLinkServiceConnectionStateProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___ManagedInstancePrivateLinkServiceConnectionStateProperty = ManagedInstancePrivateLinkServiceConnectionStateProperty

@typing_extensions.final
class ManagedInstancePrivateEndpointProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ManagedInstancePrivateEndpointProperty = ManagedInstancePrivateEndpointProperty

@typing_extensions.final
class ManagedInstancesKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    server_key_type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        server_key_type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "server_key_type", b"server_key_type", "uri", b"uri"]) -> None: ...

global___ManagedInstancesKeys = ManagedInstancesKeys

@typing_extensions.final
class ManagedInstancesEncryptionProtector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_ROTATION_ENABLED_FIELD_NUMBER: builtins.int
    SERVER_KEY_NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_rotation_enabled: builtins.bool
    server_key_name: builtins.str
    server_key_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_rotation_enabled: builtins.bool = ...,
        server_key_name: builtins.str = ...,
        server_key_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_rotation_enabled", b"auto_rotation_enabled", "name", b"name", "resource_info", b"resource_info", "server_key_name", b"server_key_name", "server_key_type", b"server_key_type"]) -> None: ...

global___ManagedInstancesEncryptionProtector = ManagedInstancesEncryptionProtector

@typing_extensions.final
class ManagedInstancesDistributedAvailabilityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIMARY_AVAILABILITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    REPLICATION_MODE_FIELD_NUMBER: builtins.int
    SECONDARY_AVAILABILITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    SOURCE_ENDPOINT_FIELD_NUMBER: builtins.int
    TARGET_DATABASE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    primary_availability_group_name: builtins.str
    replication_mode: builtins.str
    secondary_availability_group_name: builtins.str
    source_endpoint: builtins.str
    target_database: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        primary_availability_group_name: builtins.str = ...,
        replication_mode: builtins.str = ...,
        secondary_availability_group_name: builtins.str = ...,
        source_endpoint: builtins.str = ...,
        target_database: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "primary_availability_group_name", b"primary_availability_group_name", "replication_mode", b"replication_mode", "resource_info", b"resource_info", "secondary_availability_group_name", b"secondary_availability_group_name", "source_endpoint", b"source_endpoint", "target_database", b"target_database"]) -> None: ...

global___ManagedInstancesDistributedAvailabilityGroups = ManagedInstancesDistributedAvailabilityGroups

@typing_extensions.final
class ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASELINE_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def baseline_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseVulnerabilityAssessmentRuleBaselineItem]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        baseline_results: collections.abc.Iterable[global___DatabaseVulnerabilityAssessmentRuleBaselineItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_results", b"baseline_results", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines = ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines

@typing_extensions.final
class DatabaseVulnerabilityAssessmentRuleBaselineItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        result: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___DatabaseVulnerabilityAssessmentRuleBaselineItem = DatabaseVulnerabilityAssessmentRuleBaselineItem

@typing_extensions.final
class ManagedInstancesDatabasesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ManagedInstancesDatabasesVulnerabilityAssessments = ManagedInstancesDatabasesVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ManagedInstancesDatabasesTransparentDataEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___ManagedInstancesDatabasesTransparentDataEncryption = ManagedInstancesDatabasesTransparentDataEncryption

@typing_extensions.final
class ManagedInstancesDatabasesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ManagedInstancesDatabasesSecurityAlertPolicies = ManagedInstancesDatabasesSecurityAlertPolicies

@typing_extensions.final
class ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_ID_FIELD_NUMBER: builtins.int
    LABEL_ID_FIELD_NUMBER: builtins.int
    LABEL_NAME_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    information_type: builtins.str
    information_type_id: builtins.str
    label_id: builtins.str
    label_name: builtins.str
    rank: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        information_type: builtins.str = ...,
        information_type_id: builtins.str = ...,
        label_id: builtins.str = ...,
        label_name: builtins.str = ...,
        rank: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["information_type", b"information_type", "information_type_id", b"information_type_id", "label_id", b"label_id", "label_name", b"label_name", "name", b"name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels = ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels

@typing_extensions.final
class ManagedInstancesDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    retention_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        retention_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies = ManagedInstancesDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesDatabasesBackupLongTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MONTHLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEKLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEK_OF_YEAR_FIELD_NUMBER: builtins.int
    YEARLY_RETENTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    monthly_retention: builtins.str
    weekly_retention: builtins.str
    week_of_year: builtins.int
    yearly_retention: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        monthly_retention: builtins.str = ...,
        weekly_retention: builtins.str = ...,
        week_of_year: builtins.int = ...,
        yearly_retention: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monthly_retention", b"monthly_retention", "name", b"name", "resource_info", b"resource_info", "week_of_year", b"week_of_year", "weekly_retention", b"weekly_retention", "yearly_retention", b"yearly_retention"]) -> None: ...

global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies = ManagedInstancesDatabasesBackupLongTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_COMPLETE_RESTORE_FIELD_NUMBER: builtins.int
    CATALOG_COLLATION_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    LAST_BACKUP_NAME_FIELD_NUMBER: builtins.int
    LONG_TERM_RETENTION_BACKUP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    RECOVERABLE_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORABLE_DROPPED_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_TOKEN_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_URI_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_BACKUP_SHORT_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_TRANSPARENT_DATA_ENCRYPTION_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_BACKUP_LONG_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    auto_complete_restore: builtins.bool
    catalog_collation: builtins.str
    collation: builtins.str
    create_mode: builtins.str
    last_backup_name: builtins.str
    long_term_retention_backup_resource_id: builtins.str
    recoverable_database_id: builtins.str
    restorable_dropped_database_id: builtins.str
    restore_point_in_time: builtins.str
    source_database_id: builtins.str
    storage_container_sas_token: builtins.str
    storage_container_uri: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_instances_databases_backup_short_term_retention_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies]: ...
    @property
    def managed_instances_databases_security_alert_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesSecurityAlertPolicies]: ...
    @property
    def managed_instances_databases_transparent_data_encryption(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesTransparentDataEncryption]: ...
    @property
    def managed_instances_databases_vulnerability_assessments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesVulnerabilityAssessments]: ...
    @property
    def managed_instances_databases_backup_long_term_retention_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_complete_restore: builtins.bool = ...,
        catalog_collation: builtins.str = ...,
        collation: builtins.str = ...,
        create_mode: builtins.str = ...,
        last_backup_name: builtins.str = ...,
        long_term_retention_backup_resource_id: builtins.str = ...,
        recoverable_database_id: builtins.str = ...,
        restorable_dropped_database_id: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        source_database_id: builtins.str = ...,
        storage_container_sas_token: builtins.str = ...,
        storage_container_uri: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_instances_databases_backup_short_term_retention_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies] | None = ...,
        managed_instances_databases_security_alert_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesSecurityAlertPolicies] | None = ...,
        managed_instances_databases_transparent_data_encryption: collections.abc.Iterable[global___ManagedInstancesDatabasesTransparentDataEncryption] | None = ...,
        managed_instances_databases_vulnerability_assessments: collections.abc.Iterable[global___ManagedInstancesDatabasesVulnerabilityAssessments] | None = ...,
        managed_instances_databases_backup_long_term_retention_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_complete_restore", b"auto_complete_restore", "catalog_collation", b"catalog_collation", "collation", b"collation", "create_mode", b"create_mode", "last_backup_name", b"last_backup_name", "location", b"location", "long_term_retention_backup_resource_id", b"long_term_retention_backup_resource_id", "managed_instances_databases_backup_long_term_retention_policies", b"managed_instances_databases_backup_long_term_retention_policies", "managed_instances_databases_backup_short_term_retention_policies", b"managed_instances_databases_backup_short_term_retention_policies", "managed_instances_databases_security_alert_policies", b"managed_instances_databases_security_alert_policies", "managed_instances_databases_transparent_data_encryption", b"managed_instances_databases_transparent_data_encryption", "managed_instances_databases_vulnerability_assessments", b"managed_instances_databases_vulnerability_assessments", "name", b"name", "recoverable_database_id", b"recoverable_database_id", "resource_info", b"resource_info", "restorable_dropped_database_id", b"restorable_dropped_database_id", "restore_point_in_time", b"restore_point_in_time", "source_database_id", b"source_database_id", "storage_container_sas_token", b"storage_container_sas_token", "storage_container_uri", b"storage_container_uri", "tags", b"tags"]) -> None: ...

global___ManagedInstancesDatabases = ManagedInstancesDatabases

@typing_extensions.final
class ManagedInstancesAzureADOnlyAuthentications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    azure_ad_only_authentication: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_ad_only_authentication", b"azure_ad_only_authentication", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesAzureADOnlyAuthentications = ManagedInstancesAzureADOnlyAuthentications

@typing_extensions.final
class ManagedInstancesAdministrators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_type: builtins.str
    login: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_type: builtins.str = ...,
        login: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "login", b"login", "name", b"name", "resource_info", b"resource_info", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedInstancesAdministrators = ManagedInstancesAdministrators

@typing_extensions.final
class ManagedInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMINISTRATORS_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    DNS_ZONE_PARTNER_FIELD_NUMBER: builtins.int
    INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_CREATE_MODE_FIELD_NUMBER: builtins.int
    MINIMAL_TLS_VERSION_FIELD_NUMBER: builtins.int
    PRIMARY_USER_ASSIGNED_IDENTITY_ID_FIELD_NUMBER: builtins.int
    PROXY_OVERRIDE_FIELD_NUMBER: builtins.int
    PUBLIC_DATA_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    REQUESTED_BACKUP_STORAGE_REDUNDANCY_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SERVICE_PRINCIPAL_FIELD_NUMBER: builtins.int
    SOURCE_MANAGED_INSTANCE_ID_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TIMEZONE_ID_FIELD_NUMBER: builtins.int
    V_CORES_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DISTRIBUTED_AVAILABILITY_GROUPS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_ADMINISTRATORS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_AZURE_AD_ONLY_AUTHENTICATIONS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_ENCRYPTION_PROTECTOR_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_KEYS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SERVER_TRUST_CERTIFICATES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SQL_AGENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ResourceIdentity: ...
    location: builtins.str
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    @property
    def administrators(self) -> global___ManagedInstanceExternalAdministrator: ...
    collation: builtins.str
    dns_zone_partner: builtins.str
    instance_pool_id: builtins.str
    key_id: builtins.str
    license_type: builtins.str
    maintenance_configuration_id: builtins.str
    managed_instance_create_mode: builtins.str
    minimal_tls_version: builtins.str
    primary_user_assigned_identity_id: builtins.str
    proxy_override: builtins.str
    public_data_endpoint_enabled: builtins.bool
    requested_backup_storage_redundancy: builtins.str
    restore_point_in_time: builtins.str
    @property
    def service_principal(self) -> global___ServicePrincipal: ...
    source_managed_instance_id: builtins.str
    storage_size_in_gb: builtins.int
    subnet_id: builtins.str
    timezone_id: builtins.str
    v_cores: builtins.int
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_instances_distributed_availability_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDistributedAvailabilityGroups]: ...
    @property
    def managed_instances_administrators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesAdministrators]: ...
    @property
    def managed_instances_azure_ad_only_authentications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesAzureADOnlyAuthentications]: ...
    @property
    def managed_instances_encryption_protector(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesEncryptionProtector]: ...
    @property
    def managed_instances_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesKeys]: ...
    @property
    def managed_instances_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesPrivateEndpointConnections]: ...
    @property
    def managed_instances_vulnerability_assessments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesVulnerabilityAssessments]: ...
    @property
    def managed_instances_security_alert_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesSecurityAlertPolicies]: ...
    @property
    def managed_instances_server_trust_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesServerTrustCertificates]: ...
    @property
    def managed_instances_sql_agent(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesSqlAgent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ResourceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        administrators: global___ManagedInstanceExternalAdministrator | None = ...,
        collation: builtins.str = ...,
        dns_zone_partner: builtins.str = ...,
        instance_pool_id: builtins.str = ...,
        key_id: builtins.str = ...,
        license_type: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        managed_instance_create_mode: builtins.str = ...,
        minimal_tls_version: builtins.str = ...,
        primary_user_assigned_identity_id: builtins.str = ...,
        proxy_override: builtins.str = ...,
        public_data_endpoint_enabled: builtins.bool = ...,
        requested_backup_storage_redundancy: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        service_principal: global___ServicePrincipal | None = ...,
        source_managed_instance_id: builtins.str = ...,
        storage_size_in_gb: builtins.int = ...,
        subnet_id: builtins.str = ...,
        timezone_id: builtins.str = ...,
        v_cores: builtins.int = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_instances_distributed_availability_groups: collections.abc.Iterable[global___ManagedInstancesDistributedAvailabilityGroups] | None = ...,
        managed_instances_administrators: collections.abc.Iterable[global___ManagedInstancesAdministrators] | None = ...,
        managed_instances_azure_ad_only_authentications: collections.abc.Iterable[global___ManagedInstancesAzureADOnlyAuthentications] | None = ...,
        managed_instances_encryption_protector: collections.abc.Iterable[global___ManagedInstancesEncryptionProtector] | None = ...,
        managed_instances_keys: collections.abc.Iterable[global___ManagedInstancesKeys] | None = ...,
        managed_instances_private_endpoint_connections: collections.abc.Iterable[global___ManagedInstancesPrivateEndpointConnections] | None = ...,
        managed_instances_vulnerability_assessments: collections.abc.Iterable[global___ManagedInstancesVulnerabilityAssessments] | None = ...,
        managed_instances_security_alert_policies: collections.abc.Iterable[global___ManagedInstancesSecurityAlertPolicies] | None = ...,
        managed_instances_server_trust_certificates: collections.abc.Iterable[global___ManagedInstancesServerTrustCertificates] | None = ...,
        managed_instances_sql_agent: collections.abc.Iterable[global___ManagedInstancesSqlAgent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["administrators", b"administrators", "identity", b"identity", "resource_info", b"resource_info", "service_principal", b"service_principal", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "administrators", b"administrators", "collation", b"collation", "dns_zone_partner", b"dns_zone_partner", "identity", b"identity", "instance_pool_id", b"instance_pool_id", "key_id", b"key_id", "license_type", b"license_type", "location", b"location", "maintenance_configuration_id", b"maintenance_configuration_id", "managed_instance_create_mode", b"managed_instance_create_mode", "managed_instances_administrators", b"managed_instances_administrators", "managed_instances_azure_ad_only_authentications", b"managed_instances_azure_ad_only_authentications", "managed_instances_distributed_availability_groups", b"managed_instances_distributed_availability_groups", "managed_instances_encryption_protector", b"managed_instances_encryption_protector", "managed_instances_keys", b"managed_instances_keys", "managed_instances_private_endpoint_connections", b"managed_instances_private_endpoint_connections", "managed_instances_security_alert_policies", b"managed_instances_security_alert_policies", "managed_instances_server_trust_certificates", b"managed_instances_server_trust_certificates", "managed_instances_sql_agent", b"managed_instances_sql_agent", "managed_instances_vulnerability_assessments", b"managed_instances_vulnerability_assessments", "minimal_tls_version", b"minimal_tls_version", "name", b"name", "primary_user_assigned_identity_id", b"primary_user_assigned_identity_id", "proxy_override", b"proxy_override", "public_data_endpoint_enabled", b"public_data_endpoint_enabled", "requested_backup_storage_redundancy", b"requested_backup_storage_redundancy", "resource_info", b"resource_info", "restore_point_in_time", b"restore_point_in_time", "service_principal", b"service_principal", "sku", b"sku", "source_managed_instance_id", b"source_managed_instance_id", "storage_size_in_gb", b"storage_size_in_gb", "subnet_id", b"subnet_id", "tags", b"tags", "timezone_id", b"timezone_id", "v_cores", b"v_cores", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ManagedInstances = ManagedInstances

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class ServicePrincipal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ServicePrincipal = ServicePrincipal

@typing_extensions.final
class ManagedInstanceExternalAdministrator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    administrator_type: builtins.str
    azure_ad_only_authentication: builtins.bool
    login: builtins.str
    principal_type: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        administrator_type: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
        login: builtins.str = ...,
        principal_type: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "principal_type", b"principal_type", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedInstanceExternalAdministrator = ManagedInstanceExternalAdministrator

@typing_extensions.final
class ResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ResourceIdentity = ResourceIdentity



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BigtableAppProfileXSingleClusterRouting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_TRANSACTIONAL_WRITES_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    allow_transactional_writes: builtins.bool
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        allow_transactional_writes: builtins.bool = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_transactional_writes", b"allow_transactional_writes", "cluster_id", b"cluster_id"]) -> None: ...

global___BigtableAppProfileXSingleClusterRouting = BigtableAppProfileXSingleClusterRouting

@typing_extensions.final
class BigtableAppProfileXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___BigtableAppProfileXTimeouts = BigtableAppProfileXTimeouts

@typing_extensions.final
class BigtableAppProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PROFILE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IGNORE_WARNINGS_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MULTI_CLUSTER_ROUTING_CLUSTER_IDS_FIELD_NUMBER: builtins.int
    MULTI_CLUSTER_ROUTING_USE_ANY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SINGLE_CLUSTER_ROUTING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_profile_id: builtins.str
    description: builtins.str
    id: builtins.str
    ignore_warnings: builtins.bool
    instance: builtins.str
    @property
    def multi_cluster_routing_cluster_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    multi_cluster_routing_use_any: builtins.bool
    name: builtins.str
    project: builtins.str
    @property
    def single_cluster_routing(self) -> global___BigtableAppProfileXSingleClusterRouting: ...
    @property
    def timeouts(self) -> global___BigtableAppProfileXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_profile_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ignore_warnings: builtins.bool = ...,
        instance: builtins.str = ...,
        multi_cluster_routing_cluster_ids: collections.abc.Iterable[builtins.str] | None = ...,
        multi_cluster_routing_use_any: builtins.bool = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        single_cluster_routing: global___BigtableAppProfileXSingleClusterRouting | None = ...,
        timeouts: global___BigtableAppProfileXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "single_cluster_routing", b"single_cluster_routing", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_profile_id", b"app_profile_id", "description", b"description", "id", b"id", "ignore_warnings", b"ignore_warnings", "instance", b"instance", "multi_cluster_routing_cluster_ids", b"multi_cluster_routing_cluster_ids", "multi_cluster_routing_use_any", b"multi_cluster_routing_use_any", "name", b"name", "project", b"project", "resource_info", b"resource_info", "single_cluster_routing", b"single_cluster_routing", "timeouts", b"timeouts"]) -> None: ...

global___BigtableAppProfile = BigtableAppProfile

@typing_extensions.final
class BigtableGcPolicyXMaxAge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    days: builtins.float
    duration: builtins.str
    def __init__(
        self,
        *,
        days: builtins.float = ...,
        duration: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "duration", b"duration"]) -> None: ...

global___BigtableGcPolicyXMaxAge = BigtableGcPolicyXMaxAge

@typing_extensions.final
class BigtableGcPolicyXMaxVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_FIELD_NUMBER: builtins.int
    number: builtins.float
    def __init__(
        self,
        *,
        number: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["number", b"number"]) -> None: ...

global___BigtableGcPolicyXMaxVersion = BigtableGcPolicyXMaxVersion

@typing_extensions.final
class BigtableGcPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_FAMILY_FIELD_NUMBER: builtins.int
    GC_RULES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    MAX_VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    column_family: builtins.str
    gc_rules: builtins.str
    id: builtins.str
    instance_name: builtins.str
    mode: builtins.str
    project: builtins.str
    table: builtins.str
    @property
    def max_age(self) -> global___BigtableGcPolicyXMaxAge: ...
    @property
    def max_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BigtableGcPolicyXMaxVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        column_family: builtins.str = ...,
        gc_rules: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        mode: builtins.str = ...,
        project: builtins.str = ...,
        table: builtins.str = ...,
        max_age: global___BigtableGcPolicyXMaxAge | None = ...,
        max_version: collections.abc.Iterable[global___BigtableGcPolicyXMaxVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_age", b"max_age", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_family", b"column_family", "gc_rules", b"gc_rules", "id", b"id", "instance_name", b"instance_name", "max_age", b"max_age", "max_version", b"max_version", "mode", b"mode", "project", b"project", "resource_info", b"resource_info", "table", b"table"]) -> None: ...

global___BigtableGcPolicy = BigtableGcPolicy

@typing_extensions.final
class BigtableInstanceXClusterXAutoscalingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_TARGET_FIELD_NUMBER: builtins.int
    MAX_NODES_FIELD_NUMBER: builtins.int
    MIN_NODES_FIELD_NUMBER: builtins.int
    cpu_target: builtins.float
    max_nodes: builtins.float
    min_nodes: builtins.float
    def __init__(
        self,
        *,
        cpu_target: builtins.float = ...,
        max_nodes: builtins.float = ...,
        min_nodes: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_target", b"cpu_target", "max_nodes", b"max_nodes", "min_nodes", b"min_nodes"]) -> None: ...

global___BigtableInstanceXClusterXAutoscalingConfig = BigtableInstanceXClusterXAutoscalingConfig

@typing_extensions.final
class BigtableInstanceXCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    NUM_NODES_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    kms_key_name: builtins.str
    num_nodes: builtins.float
    storage_type: builtins.str
    zone: builtins.str
    @property
    def autoscaling_config(self) -> global___BigtableInstanceXClusterXAutoscalingConfig: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        num_nodes: builtins.float = ...,
        storage_type: builtins.str = ...,
        zone: builtins.str = ...,
        autoscaling_config: global___BigtableInstanceXClusterXAutoscalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "cluster_id", b"cluster_id", "kms_key_name", b"kms_key_name", "num_nodes", b"num_nodes", "storage_type", b"storage_type", "zone", b"zone"]) -> None: ...

global___BigtableInstanceXCluster = BigtableInstanceXCluster

@typing_extensions.final
class BigtableInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deletion_protection: builtins.bool
    display_name: builtins.str
    id: builtins.str
    instance_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BigtableInstanceXCluster]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deletion_protection: builtins.bool = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        instance_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        cluster: collections.abc.Iterable[global___BigtableInstanceXCluster] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "deletion_protection", b"deletion_protection", "display_name", b"display_name", "id", b"id", "instance_type", b"instance_type", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___BigtableInstance = BigtableInstance

@typing_extensions.final
class BigtableInstanceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BigtableInstanceIamBindingXCondition = BigtableInstanceIamBindingXCondition

@typing_extensions.final
class BigtableInstanceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___BigtableInstanceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___BigtableInstanceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___BigtableInstanceIamBinding = BigtableInstanceIamBinding

@typing_extensions.final
class BigtableInstanceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BigtableInstanceIamMemberXCondition = BigtableInstanceIamMemberXCondition

@typing_extensions.final
class BigtableInstanceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___BigtableInstanceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___BigtableInstanceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___BigtableInstanceIamMember = BigtableInstanceIamMember

@typing_extensions.final
class BigtableInstanceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance", b"instance", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___BigtableInstanceIamPolicy = BigtableInstanceIamPolicy

@typing_extensions.final
class BigtableTableXColumnFamily(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAMILY_FIELD_NUMBER: builtins.int
    family: builtins.str
    def __init__(
        self,
        *,
        family: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["family", b"family"]) -> None: ...

global___BigtableTableXColumnFamily = BigtableTableXColumnFamily

@typing_extensions.final
class BigtableTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SPLIT_KEYS_FIELD_NUMBER: builtins.int
    COLUMN_FAMILY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    instance_name: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def split_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def column_family(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BigtableTableXColumnFamily]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        split_keys: collections.abc.Iterable[builtins.str] | None = ...,
        column_family: collections.abc.Iterable[global___BigtableTableXColumnFamily] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_family", b"column_family", "id", b"id", "instance_name", b"instance_name", "name", b"name", "project", b"project", "resource_info", b"resource_info", "split_keys", b"split_keys"]) -> None: ...

global___BigtableTable = BigtableTable

@typing_extensions.final
class BigtableTableIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BigtableTableIamBindingXCondition = BigtableTableIamBindingXCondition

@typing_extensions.final
class BigtableTableIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    table: builtins.str
    @property
    def condition(self) -> global___BigtableTableIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        table: builtins.str = ...,
        condition: global___BigtableTableIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "table", b"table"]) -> None: ...

global___BigtableTableIamBinding = BigtableTableIamBinding

@typing_extensions.final
class BigtableTableIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BigtableTableIamMemberXCondition = BigtableTableIamMemberXCondition

@typing_extensions.final
class BigtableTableIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    table: builtins.str
    @property
    def condition(self) -> global___BigtableTableIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        table: builtins.str = ...,
        condition: global___BigtableTableIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "table", b"table"]) -> None: ...

global___BigtableTableIamMember = BigtableTableIamMember

@typing_extensions.final
class BigtableTableIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    policy_data: builtins.str
    project: builtins.str
    table: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        table: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance", b"instance", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "table", b"table"]) -> None: ...

global___BigtableTableIamPolicy = BigtableTableIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SecurityGroupEgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EGRESS_FIELD_NUMBER: builtins.int
    @property
    def egress(self) -> global___Egress: ...
    def __init__(
        self,
        *,
        egress: global___Egress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["egress", b"egress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["egress", b"egress"]) -> None: ...

global___SecurityGroupEgress = SecurityGroupEgress

@typing_extensions.final
class SecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGRESS_FIELD_NUMBER: builtins.int
    @property
    def ingress(self) -> global___Ingress: ...
    def __init__(
        self,
        *,
        ingress: global___Ingress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ingress", b"ingress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingress", b"ingress"]) -> None: ...

global___SecurityGroupIngress = SecurityGroupIngress

@typing_extensions.final
class SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_EGRESS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    group_description: builtins.str
    group_name: builtins.str
    @property
    def security_group_egress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupEgress]: ...
    @property
    def security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupIngress]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        group_description: builtins.str = ...,
        group_name: builtins.str = ...,
        security_group_egress: collections.abc.Iterable[global___SecurityGroupEgress] | None = ...,
        security_group_ingress: collections.abc.Iterable[global___SecurityGroupIngress] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_description", b"group_description", "group_name", b"group_name", "resource_info", b"resource_info", "security_group_egress", b"security_group_egress", "security_group_ingress", b"security_group_ingress", "tags", b"tags", "vpc_id", b"vpc_id"]) -> None: ...

global___SecurityGroup = SecurityGroup

@typing_extensions.final
class Egress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_IP_FIELD_NUMBER: builtins.int
    CIDR_IPV6_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_PREFIX_LIST_ID_FIELD_NUMBER: builtins.int
    DESTINATION_SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    FROM_PORT_FIELD_NUMBER: builtins.int
    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    TO_PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_ip: builtins.str
    cidr_ipv6: builtins.str
    description: builtins.str
    destination_prefix_list_id: builtins.str
    destination_security_group_id: builtins.str
    from_port: builtins.int
    ip_protocol: builtins.str
    to_port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_ip: builtins.str = ...,
        cidr_ipv6: builtins.str = ...,
        description: builtins.str = ...,
        destination_prefix_list_id: builtins.str = ...,
        destination_security_group_id: builtins.str = ...,
        from_port: builtins.int = ...,
        ip_protocol: builtins.str = ...,
        to_port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ip", b"cidr_ip", "cidr_ipv6", b"cidr_ipv6", "description", b"description", "destination_prefix_list_id", b"destination_prefix_list_id", "destination_security_group_id", b"destination_security_group_id", "from_port", b"from_port", "ip_protocol", b"ip_protocol", "resource_info", b"resource_info", "to_port", b"to_port"]) -> None: ...

global___Egress = Egress

@typing_extensions.final
class Ingress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_IP_FIELD_NUMBER: builtins.int
    CIDR_IPV6_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SOURCE_PREFIX_LIST_ID_FIELD_NUMBER: builtins.int
    SOURCE_SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    SOURCE_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    SOURCE_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    FROM_PORT_FIELD_NUMBER: builtins.int
    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    TO_PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_ip: builtins.str
    cidr_ipv6: builtins.str
    description: builtins.str
    source_prefix_list_id: builtins.str
    source_security_group_id: builtins.str
    source_security_group_name: builtins.str
    source_security_group_owner_id: builtins.str
    from_port: builtins.int
    ip_protocol: builtins.str
    to_port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_ip: builtins.str = ...,
        cidr_ipv6: builtins.str = ...,
        description: builtins.str = ...,
        source_prefix_list_id: builtins.str = ...,
        source_security_group_id: builtins.str = ...,
        source_security_group_name: builtins.str = ...,
        source_security_group_owner_id: builtins.str = ...,
        from_port: builtins.int = ...,
        ip_protocol: builtins.str = ...,
        to_port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ip", b"cidr_ip", "cidr_ipv6", b"cidr_ipv6", "description", b"description", "from_port", b"from_port", "ip_protocol", b"ip_protocol", "resource_info", b"resource_info", "source_prefix_list_id", b"source_prefix_list_id", "source_security_group_id", b"source_security_group_id", "source_security_group_name", b"source_security_group_name", "source_security_group_owner_id", b"source_security_group_owner_id", "to_port", b"to_port"]) -> None: ...

global___Ingress = Ingress

@typing_extensions.final
class EC2_SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_FIELD_NUMBER: builtins.int
    @property
    def security_group(self) -> global___SecurityGroup: ...
    def __init__(
        self,
        *,
        security_group: global___SecurityGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["security_group", b"security_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["security_group", b"security_group"]) -> None: ...

global___EC2_SecurityGroup = EC2_SecurityGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSslCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeSslCertificateXTimeouts = ComputeSslCertificateXTimeouts

@typing_extensions.final
class ComputeSslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate: builtins.str
    certificate_id: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    name_prefix: builtins.str
    private_key: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeSslCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate: builtins.str = ...,
        certificate_id: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        name_prefix: builtins.str = ...,
        private_key: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeSslCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_id", b"certificate_id", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "name_prefix", b"name_prefix", "private_key", b"private_key", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSslCertificate = ComputeSslCertificate

@typing_extensions.final
class ComputeSslPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSslPolicyXTimeouts = ComputeSslPolicyXTimeouts

@typing_extensions.final
class ComputeSslPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOM_FEATURES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_FEATURES_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    @property
    def custom_features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    @property
    def enabled_features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    fingerprint: builtins.str
    id: builtins.str
    min_tls_version: builtins.str
    name: builtins.str
    profile: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeSslPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        custom_features: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        enabled_features: collections.abc.Iterable[builtins.str] | None = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        min_tls_version: builtins.str = ...,
        name: builtins.str = ...,
        profile: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeSslPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "custom_features", b"custom_features", "description", b"description", "enabled_features", b"enabled_features", "fingerprint", b"fingerprint", "id", b"id", "min_tls_version", b"min_tls_version", "name", b"name", "profile", b"profile", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSslPolicy = ComputeSslPolicy



from dataclasses import dataclass
from enum import Enum
from typing import Union, List



class PolicyProvider(Enum):
    AZURE_POLICY = 1
    AWS_CONFIG_POLICY = 2
    KUBE_BENCH = 3
    OTHER = 4


class SourceProvider(Enum):
    AWS = 1
    AZURE = 2
    KUBERNETES = 3
    GCP = 4
    NIST = 5
    CSA = 6
    CIS = 7
    OTHER = 8


@dataclass
class Policy:
    """Class to represent a Policy and reference metadata"""
    name: str
    description: str
    provider: Union[PolicyProvider, SourceProvider]
    url: str


@dataclass()
class Validation:
    """Class to represent Validation metadata."""
    name: str
    description: str
    implements: List[Policy]
    references: List[Policy]
    coverage: str




from typing import Dict, Type
from google.protobuf.reflection import GeneratedProtocolMessageType

from models.azure.azure_microsoft_recoveryservices_backup_pb2 import Microsoft_RecoveryServices_Backup
from models.azure.azure_microsoft_network_privateendpoints_pb2 import Microsoft_Network_privateEndpoints
from models.azure.azure_microsoft_compute_pb2 import Microsoft_Compute
from models.azure.azure_microsoft_compute_virtualmachines_pb2 import Microsoft_Compute_VirtualMachines
from models.azure.azure_microsoft_compute_virtualmachinescalesets_pb2 import Microsoft_Compute_VirtualMachineScaleSets
from models.azure.azure_microsoft_recoveryservices_pb2 import Microsoft_RecoveryServices
from models.azure.azure_microsoft_servicebus_pb2 import Microsoft_ServiceBus
from models.azure.azure_microsoft_cdn_pb2 import Microsoft_Cdn
from models.azure.azure_microsoft_network_privatelinkservices_pb2 import Microsoft_Network_privateLinkServices
from models.azure.azure_microsoft_devices_pb2 import Microsoft_Devices
from models.azure.azure_microsoft_keyvault_pb2 import Microsoft_KeyVault
from models.azure.azure_microsoft_containerservice_pb2 import Microsoft_ContainerService
from models.azure.azure_microsoft_network_virtualnetworks_pb2 import Microsoft_Network_virtualNetworks
from models.azure.azure_microsoft_network_dnszones_pb2 import Microsoft_Network_dnsZones
from models.azure.azure_microsoft_apimanagement_pb2 import Microsoft_ApiManagement
from models.azure.azure_microsoft_web_pb2 import Microsoft_Web
from models.azure.azure_microsoft_sql_servers_pb2 import Microsoft_Sql_Servers
from models.azure.azure_microsoft_sql_databases_pb2 import Microsoft_Sql_Databases
from models.azure.azure_microsoft_sql_managedinstances_pb2 import Microsoft_Sql_ManagedInstances
from models.azure.azure_microsoft_network_routetables_pb2 import Microsoft_Network_routeTables
from models.azure.azure_microsoft_aad_pb2 import Microsoft_AAD
from models.azure.azure_microsoft_containerregistry_pb2 import Microsoft_ContainerRegistry
from models.azure.azure_microsoft_sql_pb2 import Microsoft_Sql
from models.azure.azure_microsoft_iotsecurity_pb2 import Microsoft_IoTSecurity
from models.azure.azure_microsoft_network_loadbalancers_pb2 import Microsoft_Network_loadBalancers
from models.azure.azure_microsoft_network_privatednszones_pb2 import Microsoft_Network_privateDnsZones
from models.azure.azure_microsoft_network_applicationgateways_pb2 import Microsoft_Network_applicationGateways
from models.azure.azure_microsoft_network_trafficmanager_pb2 import Microsoft_Network_TrafficManager
from models.azure.azure_microsoft_healthcareapis_pb2 import Microsoft_HealthcareApis
from models.azure.azure_microsoft_iotcentral_pb2 import Microsoft_IotCentral
from models.azure.azure_microsoft_network_frontdoor_pb2 import Microsoft_Network_FrontDoor
from models.azure.azure_microsoft_elastic_pb2 import Microsoft_Elastic
from models.azure.azure_microsoft_storage_pb2 import Microsoft_Storage
from models.azure.azure_microsoft_network_frontdoor_networkexperimentprofiles_pb2 import Microsoft_Network_FrontDoor_NetworkExperimentProfiles
from models.azure.azure_microsoft_cache_pb2 import Microsoft_Cache
from models.azure.azure_microsoft_network_pb2 import Microsoft_Network
from models.azure.azure_microsoft_documentdb_pb2 import Microsoft_DocumentDB
from models.azure.azure_microsoft_streamanalytics_pb2 import Microsoft_StreamAnalytics
from models.azure.azure_microsoft_kubernetes_pb2 import Microsoft_Kubernetes
from models.azure.azure_microsoft_recoveryservices_siterecovery_pb2 import Microsoft_RecoveryServices_SiteRecovery
from models.azure.azure_microsoft_network_networksecuritygroups_pb2 import Microsoft_Network_networkSecurityGroups
from models.azure.azure_microsoft_eventgrid_pb2 import Microsoft_EventGrid
from models.azure.azure_microsoft_network_firewallpolicies_pb2 import Microsoft_Network_firewallPolicies
from models.azure.azure_microsoft_app_containerapps_pb2 import Microsoft_App_containerApps
from models.aws.aws_ec2_vpcendpoint_pb2 import EC2_VPCEndpoint
from models.aws.aws_ec2_subnet_pb2 import EC2_Subnet
from models.aws.aws_codepipeline_pb2 import CodePipeline
from models.aws.aws_kinesisfirehose_pb2 import KinesisFirehose
from models.aws.aws_workspaces_pb2 import WorkSpaces
from models.aws.aws_emr_pb2 import EMR
from models.aws.aws_cloudformation_pb2 import CloudFormation
from models.aws.aws_fms_pb2 import FMS
from models.aws.aws_codebuild_pb2 import CodeBuild
from models.aws.aws_eks_pb2 import EKS
from models.aws.aws_ec2_pb2 import EC2
from models.aws.aws_glue_pb2 import Glue
from models.aws.aws_greengrass_pb2 import Greengrass
from models.aws.aws_codeguruprofiler_pb2 import CodeGuruProfiler
from models.aws.aws_imagebuilder_pb2 import ImageBuilder
from models.aws.aws_route53resolver_pb2 import Route53Resolver
from models.aws.aws_config_pb2 import Config
from models.aws.aws_qldb_pb2 import QLDB
from models.aws.aws_chatbot_pb2 import Chatbot
from models.aws.aws_neptune_pb2 import Neptune
from models.aws.aws_ec2_instance_pb2 import EC2_Instance
from models.aws.aws_wafregional_pb2 import WAFRegional
from models.aws.aws_sso_pb2 import SSO
from models.aws.aws_autoscalingplans_pb2 import AutoScalingPlans
from models.aws.aws_eventschemas_pb2 import EventSchemas
from models.aws.aws_appflow_pb2 import AppFlow
from models.aws.aws_sdb_pb2 import SDB
from models.aws.aws_appsync_pb2 import AppSync
from models.aws.aws_gamelift_pb2 import GameLift
from models.aws.aws_waf_pb2 import WAF
from models.aws.aws_docdb_pb2 import DocDB
from models.aws.aws_datapipeline_pb2 import DataPipeline
from models.aws.aws_ecr_pb2 import ECR
from models.aws.aws_appconfig_pb2 import AppConfig
from models.aws.aws_amplify_pb2 import Amplify
from models.aws.aws_ssm_pb2 import SSM
from models.aws.aws_detective_pb2 import Detective
from models.aws.aws_ec2_dhcpoptions_pb2 import EC2_DHCPOptions
from models.aws.aws_iot1click_pb2 import IoT1Click
from models.aws.aws_apigatewayv2_pb2 import ApiGatewayV2
from models.aws.aws_globalaccelerator_pb2 import GlobalAccelerator
from models.aws.aws_elasticloadbalancingv2_pb2 import ElasticLoadBalancingV2
from models.aws.aws_backup_pb2 import Backup
from models.aws.aws_athena_pb2 import Athena
from models.aws.aws_apigateway_pb2 import ApiGateway
from models.aws.aws_ec2_vpc_pb2 import EC2_VPC
from models.aws.aws_elasticsearch_pb2 import Elasticsearch
from models.aws.aws_codegurureviewer_pb2 import CodeGuruReviewer
from models.aws.aws_lambda_pb2 import Lambda
from models.aws.aws_ram_pb2 import RAM
from models.aws.aws_rds_dbcluster_pb2 import RDS_DBCluster
from models.aws.aws_redshift_pb2 import Redshift
from models.aws.aws_cloudwatch_pb2 import CloudWatch
from models.aws.aws_dms_pb2 import DMS
from models.aws.aws_sqs_pb2 import SQS
from models.aws.aws_amazonmq_pb2 import AmazonMQ
from models.aws.aws_accessanalyzer_pb2 import AccessAnalyzer
from models.aws.aws_ecs_pb2 import ECS
from models.aws.aws_kinesisanalytics_pb2 import KinesisAnalytics
from models.aws.aws_elasticloadbalancing_pb2 import ElasticLoadBalancing
from models.aws.aws_dynamodb_pb2 import DynamoDB
from models.aws.aws_route53_pb2 import Route53
from models.aws.aws_msk_pb2 import MSK
from models.aws.aws_applicationinsights_pb2 import ApplicationInsights
from models.aws.aws_cognito_pb2 import Cognito
from models.aws.aws_appmesh_pb2 import AppMesh
from models.aws.aws_securityhub_pb2 import SecurityHub
from models.aws.aws_codestar_pb2 import CodeStar
from models.aws.aws_elasticache_cachecluster_pb2 import ElastiCache_CacheCluster
from models.aws.aws_elasticache_replicationgroup_pb2 import ElastiCache_ReplicationGroup
from models.aws.aws_alexa_ask_pb2 import Alexa_ASK
from models.aws.aws_stepfunctions_pb2 import StepFunctions
from models.aws.aws_ec2_networkacl_pb2 import EC2_NetworkACL
from models.aws.aws_opsworkscm_pb2 import OpsWorksCM
from models.aws.aws_s3_pb2 import S3
from models.aws.aws_kinesis_pb2 import Kinesis
from models.aws.aws_directoryservice_pb2 import DirectoryService
from models.aws.aws_efs_pb2 import EFS
from models.aws.aws_dlm_pb2 import DLM
from models.aws.aws_acmpca_pb2 import ACMPCA
from models.aws.aws_resourcegroups_pb2 import ResourceGroups
from models.aws.aws_synthetics_pb2 import Synthetics
from models.aws.aws_budgets_pb2 import Budgets
from models.aws.aws_batch_pb2 import Batch
from models.aws.aws_managedblockchain_pb2 import ManagedBlockchain
from models.aws.aws_rds_dbinstance_pb2 import RDS_DBInstance
from models.aws.aws_applicationautoscaling_pb2 import ApplicationAutoScaling
from models.aws.aws_servicecatalog_pb2 import ServiceCatalog
from models.aws.aws_macie_pb2 import Macie
from models.aws.aws_sns_pb2 import SNS
from models.aws.aws_guardduty_pb2 import GuardDuty
from models.aws.aws_logs_pb2 import Logs
from models.aws.aws_cloud9_pb2 import Cloud9
from models.aws.aws_sagemaker_pb2 import SageMaker
from models.aws.aws_codecommit_pb2 import CodeCommit
from models.aws.aws_lakeformation_pb2 import LakeFormation
from models.aws.aws_cloudtrail_pb2 import CloudTrail
from models.aws.aws_robomaker_pb2 import RoboMaker
from models.aws.aws_networkmanager_pb2 import NetworkManager
from models.aws.aws_rds_pb2 import RDS
from models.aws.aws_mediaconvert_pb2 import MediaConvert
from models.aws.aws_secretsmanager_pb2 import SecretsManager
from models.aws.aws_transfer_pb2 import Transfer
from models.aws.aws_wafv2_pb2 import WAFv2
from models.aws.aws_elasticbeanstalk_pb2 import ElasticBeanstalk
from models.aws.aws_autoscaling_pb2 import AutoScaling
from models.aws.aws_iam_pb2 import IAM
from models.aws.aws_cloudfront_pb2 import CloudFront
from models.aws.aws_kms_pb2 import KMS
from models.aws.aws_fsx_pb2 import FSx
from models.aws.aws_groundstation_pb2 import GroundStation
from models.aws.aws_codestarnotifications_pb2 import CodeStarNotifications
from models.aws.aws_events_pb2 import Events
from models.aws.aws_opsworks_pb2 import OpsWorks
from models.aws.aws_inspector_pb2 import Inspector
from models.aws.aws_ec2_route_pb2 import EC2_Route
from models.aws.aws_ec2_securitygroup_pb2 import EC2_SecurityGroup
from models.aws.aws_dynamodb_table_pb2 import DynamoDB_Table
from models.aws.aws_codedeploy_pb2 import CodeDeploy
from models.aws.aws_iotevents_pb2 import IoTEvents
from models.aws.aws_kinesisanalyticsv2_pb2 import KinesisAnalyticsV2
from models.aws.aws_servicediscovery_pb2 import ServiceDiscovery
from models.aws.aws_iot_pb2 import IoT
from models.aws.aws_iotanalytics_pb2 import IoTAnalytics
from models.aws.aws_codestarconnections_pb2 import CodeStarConnections
from models.aws.aws_certificatemanager_pb2 import CertificateManager
from models.aws.aws_cassandra_pb2 import Cassandra
from models.gcp.gcp_google_storage_bundle_pb2 import GoogleStorage
from models.gcp.gcp_google_app_engine_bundle_pb2 import GoogleAppEngine
from models.gcp.gcp_google_kms_bundle_pb2 import GoogleKms
from models.gcp.gcp_google_dns_bundle_pb2 import GoogleDns
from models.gcp.gcp_google_sql_bundle_pb2 import GoogleSql
from models.gcp.gcp_google_redis_bundle_pb2 import GoogleRedis
from models.gcp.gcp_google_container_bundle_pb2 import GoogleContainer
from models.gcp.gcp_google_pubsub_bundle_pb2 import GooglePubsub
from models.gcp.gcp_google_secret_manager_bundle_pb2 import GoogleSecretManager
from models.gcp.gcp_google_compute_firewall_bundle_pb2 import GoogleComputeFirewall
from models.gcp.gcp_google_compute_firewall_policy_bundle_pb2 import GoogleComputeFirewallPolicy
from models.gcp.gcp_google_compute_instance_bundle_pb2 import GoogleComputeInstance
from models.gcp.gcp_google_compute_network_bundle_pb2 import GoogleComputeNetwork
from models.gcp.gcp_google_compute_route_bundle_pb2 import GoogleComputeRoute
from models.gcp.gcp_google_compute_subnetwork_bundle_pb2 import GoogleComputeSubnetwork
from models.gcp.gcp_google_spanner_bundle_pb2 import GoogleSpanner
from models.gcp.gcp_google_cloud_tasks_bundle_pb2 import GoogleCloudTasks
from models.gcp.gcp_google_certificate_manager_bundle_pb2 import GoogleCertificateManager
from models.gcp.gcp_google_cloudfunctions_bundle_pb2 import GoogleCloudfunctions
from models.kubernetes.kubernetes_kubernetes_namespaced_bundle_pb2 import Kubernetes_Namespaced
from models.kubernetes.kubernetes_kubernetes_nonnamespaced_bundle_pb2 import Kubernetes_NonNamespaced

grpc_type_map: Dict[str, Type[GeneratedProtocolMessageType]] = {
	'type.googleapis.com/oak9.tython.azure.microsoft_recoveryservices_backup.Microsoft_RecoveryServices_Backup': Microsoft_RecoveryServices_Backup,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_privateendpoints.Microsoft_Network_privateEndpoints': Microsoft_Network_privateEndpoints,
	'type.googleapis.com/oak9.tython.azure.microsoft_compute_virtualmachines.Microsoft_Compute_VirtualMachines': Microsoft_Compute_VirtualMachines,
	'type.googleapis.com/oak9.tython.azure.microsoft_compute_virtualmachinescalesets.Microsoft_Compute_VirtualMachineScaleSets': Microsoft_Compute_VirtualMachineScaleSets,
	'type.googleapis.com/oak9.tython.azure.microsoft_recoveryservices.Microsoft_RecoveryServices': Microsoft_RecoveryServices,
	'type.googleapis.com/oak9.tython.azure.microsoft_servicebus.Microsoft_ServiceBus': Microsoft_ServiceBus,
	'type.googleapis.com/oak9.tython.azure.microsoft_cdn.Microsoft_Cdn': Microsoft_Cdn,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_privatelinkservices.Microsoft_Network_privateLinkServices': Microsoft_Network_privateLinkServices,
	'type.googleapis.com/oak9.tython.azure.microsoft_devices.Microsoft_Devices': Microsoft_Devices,
	'type.googleapis.com/oak9.tython.azure.microsoft_keyvault.Microsoft_KeyVault': Microsoft_KeyVault,
	'type.googleapis.com/oak9.tython.azure.microsoft_containerservice.Microsoft_ContainerService': Microsoft_ContainerService,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_virtualnetworks.Microsoft_Network_virtualNetworks': Microsoft_Network_virtualNetworks,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_dnszones.Microsoft_Network_dnsZones': Microsoft_Network_dnsZones,
	'type.googleapis.com/oak9.tython.azure.microsoft_apimanagement.Microsoft_ApiManagement': Microsoft_ApiManagement,
	'type.googleapis.com/oak9.tython.azure.microsoft_web.Microsoft_Web': Microsoft_Web,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_routetables.Microsoft_Network_routeTables': Microsoft_Network_routeTables,
	'type.googleapis.com/oak9.tython.azure.microsoft_aad.Microsoft_AAD': Microsoft_AAD,
	'type.googleapis.com/oak9.tython.azure.microsoft_containerregistry.Microsoft_ContainerRegistry': Microsoft_ContainerRegistry,
	'type.googleapis.com/oak9.tython.azure.microsoft_sql.Microsoft_Sql': Microsoft_Sql,
 	'type.googleapis.com/oak9.tython.azure.microsoft_sql_servers.Microsoft_Sql_Servers': Microsoft_Sql_Servers,
 	'type.googleapis.com/oak9.tython.azure.microsoft_sql_managedinstances.Microsoft_Sql_ManagedInstances': Microsoft_Sql_ManagedInstances,
 	'type.googleapis.com/oak9.tython.azure.microsoft_sql_databases.Microsoft_Sql_Databases': Microsoft_Sql_Databases,
	'type.googleapis.com/oak9.tython.azure.microsoft_iotsecurity.Microsoft_IoTSecurity': Microsoft_IoTSecurity,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_loadbalancers.Microsoft_Network_loadBalancers': Microsoft_Network_loadBalancers,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_privatednszones.Microsoft_Network_privateDnsZones': Microsoft_Network_privateDnsZones,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_applicationgateways.Microsoft_Network_applicationGateways': Microsoft_Network_applicationGateways,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_trafficmanager.Microsoft_Network_TrafficManager': Microsoft_Network_TrafficManager,
	'type.googleapis.com/oak9.tython.azure.microsoft_healthcareapis.Microsoft_HealthcareApis': Microsoft_HealthcareApis,
	'type.googleapis.com/oak9.tython.azure.microsoft_iotcentral.Microsoft_IotCentral': Microsoft_IotCentral,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_frontdoor.Microsoft_Network_FrontDoor': Microsoft_Network_FrontDoor,
	'type.googleapis.com/oak9.tython.azure.microsoft_elastic.Microsoft_Elastic': Microsoft_Elastic,
	'type.googleapis.com/oak9.tython.azure.microsoft_storage.Microsoft_Storage': Microsoft_Storage,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.Microsoft_Network_FrontDoor_NetworkExperimentProfiles': Microsoft_Network_FrontDoor_NetworkExperimentProfiles,
	'type.googleapis.com/oak9.tython.azure.microsoft_cache.Microsoft_Cache': Microsoft_Cache,
	'type.googleapis.com/oak9.tython.azure.microsoft_network.Microsoft_Network': Microsoft_Network,
	'type.googleapis.com/oak9.tython.azure.microsoft_documentdb.Microsoft_DocumentDB': Microsoft_DocumentDB,
	'type.googleapis.com/oak9.tython.azure.microsoft_streamanalytics.Microsoft_StreamAnalytics': Microsoft_StreamAnalytics,
	'type.googleapis.com/oak9.tython.azure.microsoft_kubernetes.Microsoft_Kubernetes': Microsoft_Kubernetes,
	'type.googleapis.com/oak9.tython.azure.microsoft_recoveryservices_siterecovery.Microsoft_RecoveryServices_SiteRecovery': Microsoft_RecoveryServices_SiteRecovery,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_networksecuritygroups.Microsoft_Network_networkSecurityGroups': Microsoft_Network_networkSecurityGroups,
	'type.googleapis.com/oak9.tython.azure.microsoft_eventgrid.Microsoft_EventGrid': Microsoft_EventGrid,
	'type.googleapis.com/oak9.tython.azure.microsoft_network_firewallpolicies.Microsoft_Network_firewallPolicies': Microsoft_Network_firewallPolicies,
    'type.googleapis.com/oak9.tython.azure.microsoft_app_containerapps.Microsoft_App_containerApps': Microsoft_App_containerApps,
	'type.googleapis.com/oak9.tython.aws.ec2_vpcendpoint.EC2_VPCEndpoint': EC2_VPCEndpoint,
	'type.googleapis.com/oak9.tython.aws.ec2_subnet.EC2_Subnet': EC2_Subnet,
	'type.googleapis.com/oak9.tython.aws.codepipeline.CodePipeline': CodePipeline,
	'type.googleapis.com/oak9.tython.aws.kinesisfirehose.KinesisFirehose': KinesisFirehose,
	'type.googleapis.com/oak9.tython.aws.workspaces.WorkSpaces': WorkSpaces,
	'type.googleapis.com/oak9.tython.aws.emr.EMR': EMR,
	'type.googleapis.com/oak9.tython.aws.cloudformation.CloudFormation': CloudFormation,
	'type.googleapis.com/oak9.tython.aws.fms.FMS': FMS,
	'type.googleapis.com/oak9.tython.aws.codebuild.CodeBuild': CodeBuild,
	'type.googleapis.com/oak9.tython.aws.eks.EKS': EKS,
	'type.googleapis.com/oak9.tython.aws.glue.Glue': Glue,
	'type.googleapis.com/oak9.tython.aws.greengrass.Greengrass': Greengrass,
	'type.googleapis.com/oak9.tython.aws.codeguruprofiler.CodeGuruProfiler': CodeGuruProfiler,
	'type.googleapis.com/oak9.tython.aws.imagebuilder.ImageBuilder': ImageBuilder,
	'type.googleapis.com/oak9.tython.aws.route53resolver.Route53Resolver': Route53Resolver,
	'type.googleapis.com/oak9.tython.aws.config.Config': Config,
	'type.googleapis.com/oak9.tython.aws.qldb.QLDB': QLDB,
	'type.googleapis.com/oak9.tython.aws.chatbot.Chatbot': Chatbot,
	'type.googleapis.com/oak9.tython.aws.neptune.Neptune': Neptune,
 	'type.googleapis.com/oak9.tython.aws.ec2_instance.EC2_Instance': EC2_Instance,
	'type.googleapis.com/oak9.tython.aws.wafregional.WAFRegional': WAFRegional,
	'type.googleapis.com/oak9.tython.aws.sso.SSO': SSO,
	'type.googleapis.com/oak9.tython.aws.autoscalingplans.AutoScalingPlans': AutoScalingPlans,
	'type.googleapis.com/oak9.tython.aws.eventschemas.EventSchemas': EventSchemas,
	'type.googleapis.com/oak9.tython.aws.appflow.AppFlow': AppFlow,
	'type.googleapis.com/oak9.tython.aws.sdb.SDB': SDB,
	'type.googleapis.com/oak9.tython.aws.appsync.AppSync': AppSync,
	'type.googleapis.com/oak9.tython.aws.gamelift.GameLift': GameLift,
	'type.googleapis.com/oak9.tython.aws.waf.WAF': WAF,
	'type.googleapis.com/oak9.tython.aws.docdb.DocDB': DocDB,
	'type.googleapis.com/oak9.tython.aws.datapipeline.DataPipeline': DataPipeline,
	'type.googleapis.com/oak9.tython.aws.ecr.ECR': ECR,
	'type.googleapis.com/oak9.tython.aws.appconfig.AppConfig': AppConfig,
	'type.googleapis.com/oak9.tython.aws.amplify.Amplify': Amplify,
	'type.googleapis.com/oak9.tython.aws.ssm.SSM': SSM,
	'type.googleapis.com/oak9.tython.aws.detective.Detective': Detective,
	'type.googleapis.com/oak9.tython.aws.ec2_dhcpoptions.EC2_DHCPOptions': EC2_DHCPOptions,
	'type.googleapis.com/oak9.tython.aws.iot1click.IoT1Click': IoT1Click,
	'type.googleapis.com/oak9.tython.aws.apigatewayv2.ApiGatewayV2': ApiGatewayV2,
	'type.googleapis.com/oak9.tython.aws.globalaccelerator.GlobalAccelerator': GlobalAccelerator,
	'type.googleapis.com/oak9.tython.aws.elasticloadbalancingv2.ElasticLoadBalancingV2': ElasticLoadBalancingV2,
	'type.googleapis.com/oak9.tython.aws.backup.Backup': Backup,
	'type.googleapis.com/oak9.tython.aws.athena.Athena': Athena,
	'type.googleapis.com/oak9.tython.aws.apigateway.ApiGateway': ApiGateway,
	'type.googleapis.com/oak9.tython.aws.ec2_vpc.EC2_VPC': EC2_VPC,
	'type.googleapis.com/oak9.tython.aws.elasticsearch.Elasticsearch': Elasticsearch,
	'type.googleapis.com/oak9.tython.aws.codegurureviewer.CodeGuruReviewer': CodeGuruReviewer,
	'type.googleapis.com/oak9.tython.aws.lambda.Lambda': Lambda,
	'type.googleapis.com/oak9.tython.aws.ram.RAM': RAM,
	'type.googleapis.com/oak9.tython.aws.rds_dbcluster.RDS_DBCluster': RDS_DBCluster,
	'type.googleapis.com/oak9.tython.aws.redshift.Redshift': Redshift,
	'type.googleapis.com/oak9.tython.aws.cloudwatch.CloudWatch': CloudWatch,
	'type.googleapis.com/oak9.tython.aws.dms.DMS': DMS,
	'type.googleapis.com/oak9.tython.aws.sqs.SQS': SQS,
	'type.googleapis.com/oak9.tython.aws.amazonmq.AmazonMQ': AmazonMQ,
	'type.googleapis.com/oak9.tython.aws.accessanalyzer.AccessAnalyzer': AccessAnalyzer,
	'type.googleapis.com/oak9.tython.aws.ecs.ECS': ECS,
	'type.googleapis.com/oak9.tython.aws.kinesisanalytics.KinesisAnalytics': KinesisAnalytics,
	'type.googleapis.com/oak9.tython.aws.elasticloadbalancing.ElasticLoadBalancing': ElasticLoadBalancing,
	'type.googleapis.com/oak9.tython.aws.dynamodb.DynamoDB': DynamoDB,
	'type.googleapis.com/oak9.tython.aws.route53.Route53': Route53,
	'type.googleapis.com/oak9.tython.aws.msk.MSK': MSK,
	'type.googleapis.com/oak9.tython.aws.applicationinsights.ApplicationInsights': ApplicationInsights,
	'type.googleapis.com/oak9.tython.aws.cognito.Cognito': Cognito,
	'type.googleapis.com/oak9.tython.aws.appmesh.AppMesh': AppMesh,
	'type.googleapis.com/oak9.tython.aws.securityhub.SecurityHub': SecurityHub,
	'type.googleapis.com/oak9.tython.aws.codestar.CodeStar': CodeStar,
	'type.googleapis.com/oak9.tython.aws.elasticache_cachecluster.ElastiCache_CacheCluster': ElastiCache_CacheCluster,
	'type.googleapis.com/oak9.tython.aws.elasticache_replicationgroup.ElastiCache_ReplicationGroup': ElastiCache_ReplicationGroup,
	'type.googleapis.com/oak9.tython.aws.alexa_ask.Alexa_ASK': Alexa_ASK,
	'type.googleapis.com/oak9.tython.aws.stepfunctions.StepFunctions': StepFunctions,
	'type.googleapis.com/oak9.tython.aws.ec2_networkacl.EC2_NetworkACL': EC2_NetworkACL,
	'type.googleapis.com/oak9.tython.aws.opsworkscm.OpsWorksCM': OpsWorksCM,
	'type.googleapis.com/oak9.tython.aws.s3.S3': S3,
	'type.googleapis.com/oak9.tython.aws.kinesis.Kinesis': Kinesis,
	'type.googleapis.com/oak9.tython.aws.directoryservice.DirectoryService': DirectoryService,
	'type.googleapis.com/oak9.tython.aws.efs.EFS': EFS,
	'type.googleapis.com/oak9.tython.aws.dlm.DLM': DLM,
	'type.googleapis.com/oak9.tython.aws.acmpca.ACMPCA': ACMPCA,
	'type.googleapis.com/oak9.tython.aws.resourcegroups.ResourceGroups': ResourceGroups,
	'type.googleapis.com/oak9.tython.aws.synthetics.Synthetics': Synthetics,
	'type.googleapis.com/oak9.tython.aws.budgets.Budgets': Budgets,
	'type.googleapis.com/oak9.tython.aws.batch.Batch': Batch,
	'type.googleapis.com/oak9.tython.aws.managedblockchain.ManagedBlockchain': ManagedBlockchain,
	'type.googleapis.com/oak9.tython.aws.rds_dbinstance.RDS_DBInstance': RDS_DBInstance,
	'type.googleapis.com/oak9.tython.aws.applicationautoscaling.ApplicationAutoScaling': ApplicationAutoScaling,
	'type.googleapis.com/oak9.tython.aws.servicecatalog.ServiceCatalog': ServiceCatalog,
	'type.googleapis.com/oak9.tython.aws.macie.Macie': Macie,
	'type.googleapis.com/oak9.tython.aws.sns.SNS': SNS,
	'type.googleapis.com/oak9.tython.aws.guardduty.GuardDuty': GuardDuty,
	'type.googleapis.com/oak9.tython.aws.logs.Logs': Logs,
	'type.googleapis.com/oak9.tython.aws.cloud9.Cloud9': Cloud9,
	'type.googleapis.com/oak9.tython.aws.sagemaker.SageMaker': SageMaker,
	'type.googleapis.com/oak9.tython.aws.codecommit.CodeCommit': CodeCommit,
	'type.googleapis.com/oak9.tython.aws.lakeformation.LakeFormation': LakeFormation,
	'type.googleapis.com/oak9.tython.aws.cloudtrail.CloudTrail': CloudTrail,
	'type.googleapis.com/oak9.tython.aws.robomaker.RoboMaker': RoboMaker,
	'type.googleapis.com/oak9.tython.aws.networkmanager.NetworkManager': NetworkManager,
	'type.googleapis.com/oak9.tython.aws.rds.RDS': RDS,
	'type.googleapis.com/oak9.tython.aws.mediaconvert.MediaConvert': MediaConvert,
	'type.googleapis.com/oak9.tython.aws.secretsmanager.SecretsManager': SecretsManager,
	'type.googleapis.com/oak9.tython.aws.transfer.Transfer': Transfer,
	'type.googleapis.com/oak9.tython.aws.wafv2.WAFv2': WAFv2,
	'type.googleapis.com/oak9.tython.aws.elasticbeanstalk.ElasticBeanstalk': ElasticBeanstalk,
	'type.googleapis.com/oak9.tython.aws.autoscaling.AutoScaling': AutoScaling,
	'type.googleapis.com/oak9.tython.aws.iam.IAM': IAM,
	'type.googleapis.com/oak9.tython.aws.cloudfront.CloudFront': CloudFront,
	'type.googleapis.com/oak9.tython.aws.kms.KMS': KMS,
	'type.googleapis.com/oak9.tython.aws.fsx.FSx': FSx,
	'type.googleapis.com/oak9.tython.aws.groundstation.GroundStation': GroundStation,
	'type.googleapis.com/oak9.tython.aws.codestarnotifications.CodeStarNotifications': CodeStarNotifications,
	'type.googleapis.com/oak9.tython.aws.events.Events': Events,
	'type.googleapis.com/oak9.tython.aws.opsworks.OpsWorks': OpsWorks,
	'type.googleapis.com/oak9.tython.aws.inspector.Inspector': Inspector,
	'type.googleapis.com/oak9.tython.aws.ec2_route.RouteTable': EC2_Route,
 	'type.googleapis.com/oak9.tython.aws.ec2_route.EC2_Route': EC2_Route,
	'type.googleapis.com/oak9.tython.aws.ec2_securitygroup.EC2_SecurityGroup': EC2_SecurityGroup,
	'type.googleapis.com/oak9.tython.aws.dynamodb_table.DynamoDB_Table': DynamoDB_Table,
	'type.googleapis.com/oak9.tython.aws.codedeploy.CodeDeploy': CodeDeploy,
	'type.googleapis.com/oak9.tython.aws.iotevents.IoTEvents': IoTEvents,
	'type.googleapis.com/oak9.tython.aws.kinesisanalyticsv2.KinesisAnalyticsV2': KinesisAnalyticsV2,
	'type.googleapis.com/oak9.tython.aws.servicediscovery.ServiceDiscovery': ServiceDiscovery,
    'type.googleapis.com/oak9.tython.aws.iam.IAM': IAM,
	'type.googleapis.com/oak9.tython.aws.iot.IoT': IoT,
	'type.googleapis.com/oak9.tython.aws.iotanalytics.IoTAnalytics': IoTAnalytics,
	'type.googleapis.com/oak9.tython.aws.codestarconnections.CodeStarConnections': CodeStarConnections,
	'type.googleapis.com/oak9.tython.aws.certificatemanager.CertificateManager': CertificateManager,
	'type.googleapis.com/oak9.tython.aws.cassandra.Cassandra': Cassandra,
	'type.googleapis.com/oak9.tython.gcp.google_storage_bundle.GoogleStorage': GoogleStorage,
	'type.googleapis.com/oak9.tython.gcp.google_app_engine_bundle.GoogleAppEngine' : GoogleAppEngine,
	'type.googleapis.com/oak9.tython.gcp.google_kms_bundle.GoogleKms' : GoogleKms,
	'type.googleapis.com/oak9.tython.gcp.google_dns_bundle.GoogleDns': GoogleDns,
	'type.googleapis.com/oak9.tython.gcp.google_sql_bundle.GoogleSql': GoogleSql,
	'type.googleapis.com/oak9.tython.gcp.google_redis_bundle.GoogleRedis': GoogleRedis,
	'type.googleapis.com/oak9.tython.gcp.google_container_bundle.GoogleContainer': GoogleContainer,
	'type.googleapis.com/oak9.tython.gcp.google_pubsub_bundle.GooglePubsub': GooglePubsub,
	'type.googleapis.com/oak9.tython.gcp.google_secret_manager_bundle.GoogleSecretManager': GoogleSecretManager,
	'type.googleapis.com/oak9.tython.gcp.google_compute_firewall_bundle.GoogleComputeFirewall': GoogleComputeFirewall,
	'type.googleapis.com/oak9.tython.gcp.google_compute_firewall_policy_bundle.GoogleComputeFirewallPolicy': GoogleComputeFirewallPolicy,
	'type.googleapis.com/oak9.tython.gcp.google_compute_instance_bundle.GoogleComputeInstance': GoogleComputeInstance,
	'type.googleapis.com/oak9.tython.gcp.google_compute_network_bundle.GoogleComputeNetwork': GoogleComputeNetwork,
	'type.googleapis.com/oak9.tython.gcp.google_compute_route_bundle.GoogleComputeRoute': GoogleComputeRoute,
	'type.googleapis.com/oak9.tython.gcp.google_compute_subnetwork_bundle.GoogleComputeSubnetwork': GoogleComputeSubnetwork,
	'type.googleapis.com/oak9.tython.gcp.google_spanner_bundle.GoogleSpanner': GoogleSpanner,
	'type.googleapis.com/oak9.tython.gcp.google_cloud_tasks_bundle.GoogleCloudTasks': GoogleCloudTasks,
	'type.googleapis.com/oak9.tython.gcp.google_certificate_manager_bundle.GoogleCertificateManager': GoogleCertificateManager,
	'type.googleapis.com/oak9.tython.gcp.google_cloudfunctions_bundle.GoogleCloudfunctions': GoogleCloudfunctions,
    'type.googleapis.com/oak9.tython.kubernetes.kubernetes_namespaced_bundle.Kubernetes_Namespaced': Kubernetes_Namespaced,
    'type.googleapis.com/oak9.tython.kubernetes.kubernetes_nonnamespaced_bundle.Kubernetes_NonNamespaced': Kubernetes_NonNamespaced
}
